==> percona-xtradb-cluster_8.0.34-26.orig.tar.gz: Percona-XtraDB-Cluster-8.0.34-26/extra/coredumper/src/CMakeFiles/coredumper.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/coredumper.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/CMakeFiles/coredumper.dir/coredumper.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/thread_lister.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/CMakeFiles/coredumper.dir/thread_lister.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_CONFIG_H"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "extra/coredumper/include"
  "extra/protobuf/protobuf-3.19.4/src"
  )
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/elfcore.cc" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/CMakeFiles/coredumper.dir/elfcore.cc.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/linuxthreads.cc" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/CMakeFiles/coredumper.dir/linuxthreads.cc.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_CONFIG_H"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "extra/coredumper/include"
  "extra/protobuf/protobuf-3.19.4/src"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-xtradb-cluster_8.0.39-30.orig.tar.gz: Percona-XtraDB-Cluster-8.0.39-30/extra/coredumper/src/CMakeFiles/coredumper.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/coredumper.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/CMakeFiles/coredumper.dir/coredumper.c.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/thread_lister.c" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/CMakeFiles/coredumper.dir/thread_lister.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_CONFIG_H"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "extra/coredumper/include"
  "extra/protobuf/protobuf-24.4/src"
  )
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/elfcore.cc" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/CMakeFiles/coredumper.dir/elfcore.cc.o"
  "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/linuxthreads.cc" "/mnt/jenkins/workspace/pxc80-autobuild-RELEASE/test/percona-xtradb-cluster/extra/coredumper/src/CMakeFiles/coredumper.dir/linuxthreads.cc.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_CONFIG_H"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "WSREP_PS_VAR_VALUE_BUFF_SIZE=4096"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "wsrep-lib/include"
  "wsrep-lib/wsrep-API/v26"
  "."
  "include"
  "extra/coredumper/include"
  "extra/protobuf/protobuf-24.4/src"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
